@@ -1,5 +1,5 @@
 from fireflyalgorithm.fireflyalgorithm import FireflyAlgorithm
 
-__all__ = ['FireflyAlgorithm']
+__all__ = ["FireflyAlgorithm"]
 
-__version__ = '0.3.4'
+__version__ = "0.4.0"
